@@ -3,7 +3,7 @@ import lxml.html as lh
 
 def extract_table_rows_from_html_string(html_string):
     doc = lh.fromstring(html_string)
-    tr_elements = doc.xpath('//tr')
+    tr_elements = doc.xpath("//tr")
     keys = []
     for cell in tr_elements[0]:
         val = cell.text_content()
